@@ -1,13 +1,14 @@
 import click
 import os
 import pdb
+import sys
 
 from stoobly_agent.config.constants import env_vars
 from stoobly_agent.lib.utils.conditional_decorator import ConditionalDecorator
 
 from .app.api import run as run_api
 from .app.cli import ca_cert, config, feature, MainGroup, project, request
-from .app.cli.utils.migrate_service import migrate as migrate_database
+from .app.cli.helpers.migrate_service import migrate as migrate_database
 from .app.proxy import INTERCEPT_MODES, run as run_proxy
 from .app.settings import Settings
 
@@ -82,6 +83,10 @@ def run(**kwargs):
     if kwargs['test_script']:
         os.environ[env_vars.TEST_SCRIPT] = kwargs['test_script']
 
+    if kwargs['intercept_mode'] and kwargs['intercept_mode'] not in INTERCEPT_MODES:
+        print(f"Error: Invalid value for --intercept-mode, values: {', '.join(INTERCEPT_MODES)}", file=sys.stderr)
+        sys.exit(1)
+
     migrate_database()
 
     run_proxy(**kwargs)
\ No newline at end of file
